@@ -29,7 +29,7 @@ class Parameter():
             'param_form': self.param_form
         }
 
-    def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> dict:
+    def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False, allow_extra: bool = False) -> dict:
         for opt_k, opt_v in optional.items():
             # 没有选填参数时，填充预设的默认值
             if not checking.__contains__(opt_k):
@@ -78,8 +78,16 @@ class Parameter():
                         other={'prompt': str_data}
                     )
             except KeyError as err:
-                redundant_dict[_k] = _v  # 收集多余的参数
-        checking['redundant_dict'] = redundant_dict
+                if allow_extra:
+                    redundant_dict[_k] = _v  # 收集多余的参数
+                else:
+                    handle_abnormal(
+                        message='有多余的请求参数',
+                        status=400,
+                        other={'prompt': str(err)}
+                    )
+        if allow_extra:  # 默认不需要收集和返回额外参数
+            checking['redundant_dict'] = redundant_dict
         return checking
 
     def verification_file(self, verify_field: list, verify_suffix: list = []):
